========
Pancakes
========


.. image:: https://img.shields.io/pypi/v/pancakes.svg
        :target: https://pypi.python.org/pypi/pancakes

.. image:: https://img.shields.io/travis/gloc-mike/pancakes.svg
        :target: https://travis-ci.org/gloc-mike/pancakes

.. image:: https://readthedocs.org/projects/pancakes/badge/?version=latest
        :target: https://pancakes.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/gloc-mike/pancakes/shield.svg
     :target: https://pyup.io/repos/github/gloc-mike/pancakes/
     :alt: Updates



Pancake making utility that's really easy to use :) and FREE!


* Free software: MIT license
* Documentation: https://pancakes.readthedocs.io.


Features
--------

* Print the ingredients for a specified number of pancakes


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
